@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2012-2016 Montel Laurent <montel@kde.org>
+   Copyright (C) 2012-2017 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -26,22 +26,9 @@
 #include "importwizard_debug.h"
 
 ThunderBirdAddressBook::ThunderBirdAddressBook(const QDir &dir, ImportWizard *parent)
-    : AbstractAddressBook(parent)
+    : AbstractAddressBook(parent),
+      mDir(dir)
 {
-    readAddressBook(dir.path() + QLatin1String("/impab.mab"));
-    const QStringList filesimportab = dir.entryList(QStringList(QStringLiteral("impab-[0-9]*.map")), QDir::Files, QDir::Name);
-    Q_FOREACH (const QString &file, filesimportab) {
-        readAddressBook(dir.path() + QLatin1Char('/') + file);
-    }
-    readAddressBook(dir.path() + QLatin1String("/abook.mab"));
-
-    const QStringList files = dir.entryList(QStringList(QStringLiteral("abook-[0-9]*.map")), QDir::Files, QDir::Name);
-    Q_FOREACH (const QString &file, files) {
-        readAddressBook(dir.path() + QLatin1Char('/') + file);
-    }
-    readAddressBook(dir.path() + QLatin1String("/history.mab"));
-
-    cleanUp();
 }
 
 ThunderBirdAddressBook::~ThunderBirdAddressBook()
@@ -49,6 +36,25 @@ ThunderBirdAddressBook::~ThunderBirdAddressBook()
 
 }
 
+void ThunderBirdAddressBook::importAddressBook()
+{
+    const QString path = mDir.path();
+    readAddressBook(path + QLatin1String("/impab.mab"));
+    const QStringList filesimportab = mDir.entryList(QStringList(QStringLiteral("impab-[0-9]*.map")), QDir::Files, QDir::Name);
+    for (const QString &file : filesimportab) {
+        readAddressBook(path + QLatin1Char('/') + file);
+    }
+    readAddressBook(path + QLatin1String("/abook.mab"));
+
+    const QStringList files = mDir.entryList(QStringList(QStringLiteral("abook-[0-9]*.map")), QDir::Files, QDir::Name);
+    for (const QString &file : files) {
+        readAddressBook(path + QLatin1Char('/') + file);
+    }
+    readAddressBook(path + QLatin1String("/history.mab"));
+
+    cleanUp();
+}
+
 void ThunderBirdAddressBook::readAddressBook(const QString &filename)
 {
     MorkParser mork;
@@ -62,7 +68,7 @@ void ThunderBirdAddressBook::readAddressBook(const QString &filename)
     MorkTableMap *tables = mork.getTables(0x80);
     if (tables) {
         MorkTableMap::iterator tableIterEnd(tables->end());
-        MorkRowMap *rows = 0;
+        MorkRowMap *rows = nullptr;
         for (MorkTableMap::iterator tableIter = tables->begin(); tableIter != tableIterEnd; ++tableIter) {
             if (tableIter.key() != 0) {
                 rows = mork.getRows(0x80, &tableIter.value());
