@@ -73,11 +73,19 @@ void ThunderbirdSettings::importSettings()
                     line.contains(QStringLiteral("mailnews.tags.")) ||
                     line.contains(QStringLiteral("extensions.AutoResizeImage.")) ||
                     line.contains(QStringLiteral("mail.phishing.")) ||
-                    line.contains(QStringLiteral("mail.display_glyph"))) {
+                    line.contains(QStringLiteral("mail.display_glyph")) ||
+                    line.contains(QStringLiteral("extensions.sieve.account."))) {
                 insertIntoMap(line);
             }
         } else {
-            qCDebug(IMPORTWIZARD_LOG) << " unstored line :" << line;
+            if (!line.startsWith(QLatin1Char('#')) ||
+                    line.isEmpty() ||
+                    line.startsWith(QStringLiteral("/*")) ||
+                    line.startsWith(QStringLiteral(" */")) ||
+                    line.startsWith(QStringLiteral(" *"))) {
+                qCDebug(IMPORTWIZARD_LOG) << " unstored line :" << line;
+            }
+
         }
     }
     const QString mailAccountPreference = mHashConfig.value(QStringLiteral("mail.accountmanager.accounts")).toString();
@@ -458,6 +466,111 @@ void ThunderbirdSettings::readGlobalSettings()
 
 }
 
+void ThunderbirdSettings::importSieveSettings(QMap<QString, QVariant> &settings, const QString &userName, const QString &imapServerName)
+{
+    QString userNameSieveConverted = userName;
+    userNameSieveConverted.replace(QLatin1Char('@'), QStringLiteral("%40"));
+
+    const QString sieveKeyServerUserName = QStringLiteral("extensions.sieve.account.") + userNameSieveConverted + QLatin1Char('@') + imapServerName;
+    //user_pref("extensions.sieve.account.<username>@<server>.enabled", true);
+    if (mHashConfig.value(sieveKeyServerUserName + QStringLiteral(".enabled"), false).toBool()) {
+        settings.insert(QStringLiteral("SieveSupport"), true);
+        settings.insert(QStringLiteral("SievePort"), mHashConfig.value(sieveKeyServerUserName + QStringLiteral(".port"), 4190).toInt());
+        //TODO add more
+    }
+#if 0
+    <group name="siever">
+      <entry name="SieveSupport" type="Bool">
+        <label>Define if server supports sieve</label>
+        <default>false</default>
+      </entry>
+      <entry name="SieveReuseConfig" type="Bool">
+        <label>Define if we reuse host and login configuration</label>
+        <default>true</default>
+      </entry>
+      <entry name="SievePort" type="Int">
+        <label>Define sieve port</label>
+        <default>4190</default>
+      </entry>
+      <entry name="SieveAlternateUrl" type="String">
+        <label>Define alternate URL</label>
+      </entry>
+      <entry name="AlternateAuthentication" type="Int">
+        <label>Defines the authentication type to use for alternate server</label>
+        <default>1</default>
+      </entry>
+      <entry name="SieveVacationFilename" type="String">
+        <label>Define default sieve vacation filename</label>
+        <default>kmail-vacation.siv</default>
+      </entry>
+      <entry name="SieveCustomUsername" type="String">
+        <label>Define username used from custom server sieve url</label>
+        <default></default>
+      </entry>
+      <entry name="SieveCustomAuthentification" type="String">
+        <label>Defines the type of identification used by custom sieve server</label>
+        <default>ImapUserPassword</default>
+      </entry>
+    </group>
+
+#endif
+#if 0
+    if (mHashConfig.value(sieveKeyServerUserName + QStringLiteral(".enabled"), false).toBool()) {
+        //TODO
+        //user_pref("extensions.sieve.account.<username>@<server>.TLS", true);
+        //user_pref("extensions.sieve.account.<username>@<server>.TLS.forced", true);
+        //user_pref("extensions.sieve.account.<username>@<server>.activeAuthorization", 1);
+        //user_pref("extensions.sieve.account.<username>@<server>.activeHost", 1);
+        //user_pref("extensions.sieve.account.<username>@<server>.activeLogin", 1);
+        SieveEditorUtil::SieveServerConfig config;
+        //0 4190
+        //1 2000
+        //2 custom
+        //Default == 4190
+        //user_pref("extensions.sieve.account.<username>@<server>.port", 1255);
+        config.sieveSettings.port = mHashConfig.value(sieveKeyServerUserName + QStringLiteral(".port"), 4190).toInt();
+        //not necessary to import this one : user_pref("extensions.sieve.account.<username>@<server>.port.type", 1);
+
+        //user_pref("extensions.sieve.account.<username>@<server>.hostname", "sdfsfsqsdf");
+        const QString sieveHostName = mHashConfig.value(sieveKeyServerUserName + QStringLiteral(".hostname")).toString();
+        if (sieveHostName.isEmpty()) {
+            config.sieveSettings.serverName = imapServerName;
+        } else {
+            config.sieveSettings.serverName = sieveHostName;
+        }
+
+        const QString sieveUserName = mHashConfig.value(sieveKeyServerUserName + QStringLiteral(".login.username")).toString();
+        //user_pref("extensions.sieve.account.<username>@<server>.login.username", "newuser");
+        if (sieveUserName.isEmpty()) {
+            config.sieveSettings.userName = userName;
+        } else {
+            config.sieveSettings.userName = sieveUserName;
+        }
+
+        //not necessary to import this one : user_pref("extensions.sieve.account.<username>@<server>.proxy.type", 1);
+
+
+        //qCDebug(SIEVEEDITOR_LOG) << "imap account " << accountName;
+        const QString name = mHashConfig.value(accountName + QStringLiteral(".name")).toString();
+        bool found;
+        const int sievePort = mHashConfig.value(accountName + QStringLiteral(".port")).toInt(&found);
+        if (found) {
+            config.sieveImapAccountSettings.setPort(sievePort);
+        }
+        encryption(config, accountName);
+        addAuth(config, accountName);
+        config.sieveImapAccountSettings.setUserName(userName);
+        config.sieveImapAccountSettings.setServerName(imapServerName);
+
+        if (config.isValid()) {
+            atLeastAnAccountFound = true;
+            Q_EMIT importSetting(name, config);
+        }
+    }
+
+#endif
+}
+
 void ThunderbirdSettings::addAuth(QMap<QString, QVariant> &settings, const QString &argument, const QString &accountName)
 {
     bool found = false;
@@ -466,6 +579,7 @@ void ThunderbirdSettings::addAuth(QMap<QString, QVariant> &settings, const QStri
         if (found) {
             switch (authMethod) {
             case 0:
+                settings.insert(argument, MailTransport::Transport::EnumAuthenticationType::PLAIN);   //????
                 break;
             case 4: //Encrypted password ???
                 settings.insert(argument, MailTransport::Transport::EnumAuthenticationType::LOGIN);   //????
@@ -480,6 +594,10 @@ void ThunderbirdSettings::addAuth(QMap<QString, QVariant> &settings, const QStri
             case 7: //TLS
                 qCDebug(IMPORTWIZARD_LOG) << " authmethod method == TLS"; //????
                 break;
+            case 10: //OAuth2 verify it.
+                settings.insert(argument, MailTransport::Transport::EnumAuthenticationType::XOAUTH2);
+                qCDebug(IMPORTWIZARD_LOG) << " authmethod method == OAuth2"; //????
+                break;
             default:
                 qCDebug(IMPORTWIZARD_LOG) << " ThunderbirdSettings::addAuth unknown :" << authMethod;
                 break;
@@ -568,6 +686,8 @@ void ThunderbirdSettings::readAccount()
             if (mHashConfig.contains(trashFolderStr)) {
                 settings.insert(QStringLiteral("TrashCollection"), MailCommon::Util::convertFolderPathToCollectionId(mHashConfig.value(trashFolderStr).toString()));
             }
+            importSieveSettings(settings, userName, serverName);
+
 
             const QString agentIdentifyName = AbstractBase::createResource(QStringLiteral("akonadi_imap_resource"), name, settings);
             addCheckMailOnStartup(agentIdentifyName, loginAtStartup);
@@ -642,14 +762,10 @@ void ThunderbirdSettings::readAccount()
             qCDebug(IMPORTWIZARD_LOG) << " account type none!";
         } else if (type == QLatin1String("movemail")) {
             qCDebug(IMPORTWIZARD_LOG) << " movemail accound found and not implemented in importthunderbird";
-            //TODO
         } else if (type == QLatin1String("rss")) {
-            //TODO when akregator2 will merge in kdepim
             qCDebug(IMPORTWIZARD_LOG) << " rss resource needs to be implemented";
             continue;
         } else if (type == QLatin1String("nntp")) {
-            //TODO add config directly to knode
-            //TODO when knode will merge in kdepim
             qCDebug(IMPORTWIZARD_LOG) << " nntp resource need to be implemented";
             continue;
         } else {
@@ -683,6 +799,7 @@ void ThunderbirdSettings::readTransport()
     for (const QString &smtp : smtpList) {
         const QString smtpName = QStringLiteral("mail.smtpserver.%1").arg(smtp);
         MailTransport::Transport *mt = createTransport();
+        mt->setType(MailTransport::Transport::EnumType::SMTP);
         const QString name = mHashConfig.value(smtpName + QStringLiteral(".description")).toString();
         mt->setName(name);
         const QString hostName = mHashConfig.value(smtpName + QStringLiteral(".hostname")).toString();
